res2df
======

res2df is a Pandas DataFrame wrapper around resdata and opm.io, which
are used to access :term:`binary files outputted by the reservoir simulators <output file>` or
their :term:`input files <deck>` --- or any other tool outputting to the same
data format.

.. toctree::
   :maxdepth: 2

   introduction
   usage
   res2csv
   csv2res
   installation
   contribution
   history
   glossary

.. toctree::
   :hidden:
   :maxdepth: 10
   :caption: Python API

   res2df/res2df

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
